@@ -3,7 +3,7 @@ from rest_framework import serializers
 from dcim.api.nested_serializers import NestedPlatformSerializer
 from netbox.api.serializers import NetBoxModelSerializer
 from netbox_storage.api.nested_serializers import NestedFilesystemSerializer, NestedDriveSerializer, \
-    NestedPartitionSerializer, NestedMountedVolumeSerializer
+    NestedPartitionSerializer, NestedMountedVolumeSerializer, NestedDeviceSerializer
 from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume, StorageConfigurationLinuxVolume, \
     LinuxDevice, TemplateConfigurationLinuxVolume
 from virtualization.api.nested_serializers import NestedClusterSerializer, NestedVirtualMachineSerializer
@@ -45,6 +45,7 @@ class DriveSerializer(NetBoxModelSerializer):
 class PartitionSerializer(serializers.ModelSerializer):
     url = serializers.HyperlinkedIdentityField(view_name='plugins-api:netbox_storage-api:partition-detail')
     drive = NestedDriveSerializer(required=False, allow_null=True)
+    device = NestedDeviceSerializer(required=False, allow_null=True)
 
     class Meta:
         model = Partition
@@ -83,15 +84,12 @@ class MountedVolumeSerializer(serializers.ModelSerializer):
 
 
 class LinuxDeviceSerializer(serializers.ModelSerializer):
-    drive = NestedDriveSerializer(required=False, allow_null=True)
 
     class Meta:
         model = LinuxDevice
         fields = (
             "id",
-            "drive",
             "device",
-            "size",
             "type",
             "description",
             "created",
@@ -108,7 +106,7 @@ class StorageConfigurationLinuxVolumeSerializer(serializers.ModelSerializer):
         model = StorageConfigurationLinuxVolume
         fields = (
             "id",
-            "virtual_machine",
+            "device",
             "linux_volume",
             "created",
             "last_updated",
