@@ -337,20 +337,26 @@ class PartitionTemplateForm(NetBoxModelForm):
     class Meta:
         model = Partition
         fields = [
-            "platform",
+            "size"
         ]
 
     def save(self, *args, **kwargs):
-        print(f"ID OF drive: {self.cleaned_data['drive'].pk}")
+        print(f"drive: {self.cleaned_data['drive']}")
+        print(f"ID OF drive: {self.cleaned_data['drive'].id}")
+        print(f"ID OF drive: {self.cleaned_data['drive'].cluster}")
         # drive = Drive.objects.create()
 
         linux_device = LinuxDevice.objects.create(device='/dev/sda1', type='efi')
-        partition = Partition.objects.create(drive=self.cleaned_data['drive'], device=linux_device, size=self.cleaned_data['size'], type='vfat')
+        # partition = Partition.objects.create(drive=self.cleaned_data['drive'].id, device=linux_device, size=self.cleaned_data['size'], type='vfat')
 
-        # template_configuration = super().save(*args, **kwargs)
+        self.instance.drive = self.cleaned_data['drive']
+        self.instance.device = linux_device
+        self.instance.type = 'vfat'
+        partition = super().save(*args, **kwargs)
 
         # print(f"{self.cleaned_data['size']}")
         return partition
+        # return None
 
 
 class VolumeSimpleForm(NetBoxModelForm):
